@@ -157,6 +157,49 @@ gboolean tp_cli_channel_interface_chat_state_run_set_chat_state (TpChannel *prox
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_channel_interface_conference_signal_callback_channel_merged) (TpChannel *proxy,
+    const gchar *arg_Channel,
+    guint arg_Channel_Specific_Handle,
+    GHashTable *arg_Properties,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_conference_connect_to_channel_merged (TpChannel *proxy,
+    tp_cli_channel_interface_conference_signal_callback_channel_merged callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_interface_conference_signal_callback_channel_removed) (TpChannel *proxy,
+    const gchar *arg_Channel,
+    GHashTable *arg_Details,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_conference_connect_to_channel_removed (TpChannel *proxy,
+    tp_cli_channel_interface_conference_signal_callback_channel_removed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_interface_dtmf_signal_callback_sending_tones) (TpChannel *proxy,
+    const gchar *arg_Tones,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_dtmf_connect_to_sending_tones (TpChannel *proxy,
+    tp_cli_channel_interface_dtmf_signal_callback_sending_tones callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_interface_dtmf_signal_callback_stopped_tones) (TpChannel *proxy,
+    gboolean arg_Cancelled,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_dtmf_connect_to_stopped_tones (TpChannel *proxy,
+    tp_cli_channel_interface_dtmf_signal_callback_stopped_tones callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_channel_interface_dtmf_callback_for_start_tone) (TpChannel *proxy,
     const GError *error, gpointer user_data,
     GObject *weak_object);
@@ -201,6 +244,27 @@ gboolean tp_cli_channel_interface_dtmf_run_stop_tone (TpChannel *proxy,
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_channel_interface_dtmf_callback_for_multiple_tones) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_interface_dtmf_call_multiple_tones (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Tones,
+    tp_cli_channel_interface_dtmf_callback_for_multiple_tones callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_interface_dtmf_run_multiple_tones (TpChannel *proxy,
+    gint timeout_ms,
+    const gchar *in_Tones,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_channel_interface_destroyable_callback_for_destroy) (TpChannel *proxy,
     const GError *error, gpointer user_data,
     GObject *weak_object);
@@ -751,6 +815,16 @@ gboolean tp_cli_channel_interface_password_run_provide_password (TpChannel *prox
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_channel_interface_service_point_signal_callback_service_point_changed) (TpChannel *proxy,
+    const GValueArray *arg_Service_Point,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_service_point_connect_to_service_point_changed (TpChannel *proxy,
+    tp_cli_channel_interface_service_point_signal_callback_service_point_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_channel_interface_tube_signal_callback_tube_channel_state_changed) (TpChannel *proxy,
     guint arg_State,
     gpointer user_data, GObject *weak_object);
@@ -761,6 +835,87 @@ TpProxySignalConnection *tp_cli_channel_interface_tube_connect_to_tube_channel_s
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_channel_type_contact_search_signal_callback_search_state_changed) (TpChannel *proxy,
+    guint arg_State,
+    const gchar *arg_Error,
+    GHashTable *arg_Details,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_contact_search_connect_to_search_state_changed (TpChannel *proxy,
+    tp_cli_channel_type_contact_search_signal_callback_search_state_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_contact_search_signal_callback_search_result_received) (TpChannel *proxy,
+    GHashTable *arg_Result,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_contact_search_connect_to_search_result_received (TpChannel *proxy,
+    tp_cli_channel_type_contact_search_signal_callback_search_result_received callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_contact_search_callback_for_search) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_contact_search_call_search (TpChannel *proxy,
+    gint timeout_ms,
+    GHashTable *in_Terms,
+    tp_cli_channel_type_contact_search_callback_for_search callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_type_contact_search_run_search (TpChannel *proxy,
+    gint timeout_ms,
+    GHashTable *in_Terms,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_channel_type_contact_search_callback_for_more) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_contact_search_call_more (TpChannel *proxy,
+    gint timeout_ms,
+    tp_cli_channel_type_contact_search_callback_for_more callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_type_contact_search_run_more (TpChannel *proxy,
+    gint timeout_ms,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_channel_type_contact_search_callback_for_stop) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_contact_search_call_stop (TpChannel *proxy,
+    gint timeout_ms,
+    tp_cli_channel_type_contact_search_callback_for_stop callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_channel_type_contact_search_run_stop (TpChannel *proxy,
+    gint timeout_ms,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
 typedef void (*tp_cli_channel_type_dbus_tube_signal_callback_dbus_names_changed) (TpChannel *proxy,
     GHashTable *arg_Added,
     const GArray *arg_Removed,
