@@ -412,6 +412,16 @@ gboolean tp_cli_connection_interface_aliasing_run_set_aliases (TpConnection *pro
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_anonymity_signal_callback_anonymity_modes_changed) (TpConnection *proxy,
+    guint arg_Modes,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_anonymity_connect_to_anonymity_modes_changed (TpConnection *proxy,
+    tp_cli_connection_interface_anonymity_signal_callback_anonymity_modes_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_connection_interface_avatars_signal_callback_avatar_updated) (TpConnection *proxy,
     guint arg_Contact,
     const gchar *arg_New_Avatar_Token,
@@ -671,6 +681,16 @@ gboolean tp_cli_connection_interface_capabilities_run_get_capabilities (TpConnec
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_cellular_signal_callback_imsi_changed) (TpConnection *proxy,
+    const gchar *arg_IMSI,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_cellular_connect_to_imsi_changed (TpConnection *proxy,
+    tp_cli_connection_interface_cellular_signal_callback_imsi_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_connection_interface_contact_capabilities_signal_callback_contact_capabilities_changed) (TpConnection *proxy,
     GHashTable *arg_caps,
     gpointer user_data, GObject *weak_object);
@@ -1181,6 +1201,16 @@ gboolean tp_cli_connection_interface_requests_run_ensure_channel (TpConnection *
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_service_point_signal_callback_service_points_changed) (TpConnection *proxy,
+    const GPtrArray *arg_Service_Points,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_service_point_connect_to_service_points_changed (TpConnection *proxy,
+    tp_cli_connection_interface_service_point_signal_callback_service_points_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_connection_interface_simple_presence_signal_callback_presences_changed) (TpConnection *proxy,
     GHashTable *arg_Presence,
     gpointer user_data, GObject *weak_object);
