@@ -30,6 +30,50 @@
 
 G_BEGIN_DECLS
 
+typedef struct _TpContactInfoFieldSpec TpContactInfoFieldSpec;
+struct _TpContactInfoFieldSpec
+{
+  gchar *name;
+  GStrv parameters;
+  TpContactInfoFieldFlags flags;
+  guint max;
+  /*<private>*/
+  gpointer priv;
+};
+
+#define TP_TYPE_CONTACT_INFO_FIELD_SPEC (tp_contact_info_field_spec_get_type ())
+GType tp_contact_info_field_spec_get_type (void);
+TpContactInfoFieldSpec *tp_contact_info_field_spec_copy (
+    const TpContactInfoFieldSpec *self);
+void tp_contact_info_field_spec_free (TpContactInfoFieldSpec *self);
+
+#define TP_TYPE_CONTACT_INFO_SPEC_LIST (tp_contact_info_spec_list_get_type ())
+GType tp_contact_info_spec_list_get_type (void);
+GList *tp_contact_info_spec_list_copy (GList *list);
+void tp_contact_info_spec_list_free (GList *list);
+
+typedef struct _TpContactInfoField TpContactInfoField;
+struct _TpContactInfoField
+{
+  gchar *field_name;
+  GStrv parameters;
+  GStrv field_value;
+  /*<private>*/
+  gpointer priv;
+};
+
+#define TP_TYPE_CONTACT_INFO_FIELD (tp_contact_info_field_get_type ())
+GType tp_contact_info_field_get_type (void);
+TpContactInfoField *tp_contact_info_field_new (const gchar *field_name,
+    GStrv parameters, GStrv field_value);
+TpContactInfoField *tp_contact_info_field_copy (const TpContactInfoField *self);
+void tp_contact_info_field_free (TpContactInfoField *self);
+
+#define TP_TYPE_CONTACT_INFO_LIST (tp_contact_info_list_get_type ())
+GType tp_contact_info_list_get_type (void);
+GList *tp_contact_info_list_copy (GList *list);
+void tp_contact_info_list_free (GList *list);
+
 typedef struct _TpConnection TpConnection;
 typedef struct _TpConnectionPrivate TpConnectionPrivate;
 typedef struct _TpConnectionClass TpConnectionClass;
@@ -83,6 +127,17 @@ TpHandle tp_connection_get_self_handle (TpConnection *self);
 
 TpCapabilities * tp_connection_get_capabilities (TpConnection *self);
 
+TpContactInfoFlags tp_connection_get_contact_info_flags (TpConnection *self);
+
+GList *tp_connection_get_contact_info_supported_fields (TpConnection *self);
+
+void tp_connection_set_contact_info_async (TpConnection *self,
+    GList *info, GAsyncReadyCallback callback,
+    gpointer user_data);
+
+gboolean tp_connection_set_contact_info_finish (TpConnection *self,
+    GAsyncResult *result, GError **error);
+
 gboolean tp_connection_is_ready (TpConnection *self);
 
 #ifndef TP_DISABLE_DEPRECATED
@@ -115,6 +170,9 @@ gint tp_connection_presence_type_cmp_availability (TpConnectionPresenceType p1,
 gboolean tp_connection_parse_object_path (TpConnection *self, gchar **protocol,
     gchar **cm_name);
 
+const gchar *tp_connection_get_detailed_error (TpConnection *self,
+    const GHashTable **details);
+
 #define TP_CONNECTION_FEATURE_CORE \
   (tp_connection_get_feature_quark_core ())
 GQuark tp_connection_get_feature_quark_core (void) G_GNUC_CONST;
@@ -127,6 +185,10 @@ GQuark tp_connection_get_feature_quark_connected (void) G_GNUC_CONST;
   (tp_connection_get_feature_quark_capabilities ())
 GQuark tp_connection_get_feature_quark_capabilities (void) G_GNUC_CONST;
 
+#define TP_CONNECTION_FEATURE_CONTACT_INFO \
+  (tp_connection_get_feature_quark_contact_info ())
+GQuark tp_connection_get_feature_quark_contact_info (void) G_GNUC_CONST;
+
 /* connection-handles.c */
 
 typedef void (*TpConnectionHoldHandlesCb) (TpConnection *connection,
@@ -151,6 +213,48 @@ void tp_connection_request_handles (TpConnection *self, gint timeout_ms,
 void tp_connection_unref_handles (TpConnection *self,
     TpHandleType handle_type, guint n_handles, const TpHandle *handles);
 
+/* connection-avatars.c */
+
+typedef struct _TpAvatarRequirements TpAvatarRequirements;
+struct _TpAvatarRequirements
+{
+  GStrv supported_mime_types;
+  guint minimum_width;
+  guint minimum_height;
+  guint recommended_width;
+  guint recommended_height;
+  guint maximum_width;
+  guint maximum_height;
+  guint maximum_bytes;
+
+  /*<private>*/
+  gpointer _1;
+  gpointer _2;
+  gpointer _3;
+  gpointer _4;
+};
+
+#define TP_TYPE_AVATAR_REQUIREMENTS (tp_avatar_requirements_get_type ())
+GType tp_avatar_requirements_get_type (void);
+TpAvatarRequirements * tp_avatar_requirements_new (GStrv supported_mime_types,
+    guint minimum_width,
+    guint minimum_height,
+    guint recommended_width,
+    guint recommended_height,
+    guint maximum_width,
+    guint maximum_height,
+    guint maximum_bytes);
+TpAvatarRequirements * tp_avatar_requirements_copy (
+    const TpAvatarRequirements *self);
+void tp_avatar_requirements_destroy (TpAvatarRequirements *self);
+
+#define TP_CONNECTION_FEATURE_AVATAR_REQUIREMENTS \
+  (tp_connection_get_feature_quark_avatar_requirements ())
+GQuark tp_connection_get_feature_quark_avatar_requirements (void) G_GNUC_CONST;
+
+TpAvatarRequirements * tp_connection_get_avatar_requirements (
+    TpConnection *self);
+
 G_END_DECLS
 
 #include <telepathy-glib/_gen/tp-cli-connection.h>
