@@ -26,6 +26,7 @@
 #include <gio/gio.h>
 
 #include <telepathy-glib/defs.h>
+#include <telepathy-glib/_gen/genums.h>
 
 G_BEGIN_DECLS
 
@@ -51,8 +52,8 @@ typedef enum {
     TP_DBUS_ERROR_OBJECT_REMOVED = 8,
     TP_DBUS_ERROR_CANCELLED = 9,
     TP_DBUS_ERROR_INCONSISTENT = 10,
-    NUM_TP_DBUS_ERRORS
 } TpDBusError;
+#define NUM_TP_DBUS_ERRORS (TP_DBUS_ERROR_INCONSISTENT + 1)
 
 struct _TpProxy {
     /*<private>*/
@@ -73,8 +74,11 @@ typedef struct _TpProxyClass TpProxyClass;
 /* defined in proxy-internal.h for now */
 typedef struct _TpProxyFeature TpProxyFeature;
 
+/* XXX: hide this from the g-i scanner, since vapigen can't cope */
+#ifndef __GI_SCANNER__
 typedef const TpProxyFeature *(*TpProxyClassFeatureListFunc) (
     TpProxyClass *cls);
+#endif /* __GI_SCANNER__ */
 
 struct _TpProxyClass {
     /*<public>*/
@@ -83,9 +87,15 @@ struct _TpProxyClass {
     GQuark interface;
 
     unsigned int must_have_unique_name:1;
+    /*<private>*/
     guint _reserved_flags:31;
 
+/* XXX: hide this from the g-i scanner, since vapigen can't cope */
+#ifdef __GI_SCANNER__
+    GCallback _internal_list_features;
+#else
     TpProxyClassFeatureListFunc list_features;
+#endif /* __GI_SCANNER__ */
     GCallback _reserved[3];
     gpointer priv;
 };
@@ -118,17 +128,7 @@ GType tp_proxy_get_type (void);
                               TpProxyClass))
 
 gboolean tp_proxy_has_interface_by_id (gpointer self, GQuark iface);
-
-static inline gboolean
-_tp_proxy_inline_has_interface (gpointer self, const gchar *iface)
-{
-  GQuark q = g_quark_try_string (iface);
-
-  return q != 0 && tp_proxy_has_interface_by_id (self, q);
-}
-
-#define tp_proxy_has_interface(self, iface) \
-    (_tp_proxy_inline_has_interface (self, iface))
+gboolean tp_proxy_has_interface (gpointer self, const gchar *iface);
 
 TpDBusDaemon *tp_proxy_get_dbus_daemon (gpointer self);
 
@@ -151,8 +151,6 @@ void tp_proxy_prepare_async (gpointer self,
 gboolean tp_proxy_prepare_finish (gpointer self,
     GAsyncResult *result,
     GError **error);
-void _tp_proxy_set_features_failed (TpProxy *self,
-    const GError *error);
 
 G_END_DECLS
 
