@@ -1,6 +1,6 @@
 #ifndef __TP_SVC_GENERIC_H__
 #define __TP_SVC_GENERIC_H__
 
-#include <telepathy-glib/_gen/tp-svc-generic-interfaces.h>
+#include <telepathy-glib/_gen/tp-svc-generic.h>
 
 #endif
